from PyQt5 import QtWidgets, uic
from graphic.delta_t_plot import Delta_tCanvas
import os


class Delta_t(QtWidgets.QWidget):
    def __init__(self, parent=None):
        super().__init__(parent)
        os.chdir(r"graphic/ui")
        uic.loadUi(
            r"DeltaT_tab_c.ui",
            self,
        )
        os.chdir("../..")

        self.show()

        # Browse button
        self.pushButton_browse.clicked.connect(self._get_dir)

        # Figure widget
        self.widget_figure = Delta_tCanvas()
        # self.widget_figure.setMinimumSize(500, 400)
        self.widget_figure.setFixedSize(500, 425)
        self.widget_figure.setObjectName("widget")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 4, 3)

        # Refresh plot and start stream buttons
        self.pushButton_refreshPlot.clicked.connect(self._plot_refresh)

    def _get_dir(self):
        self.folder = str(
            QtWidgets.QFileDialog.getExistingDirectory(self, "Select Directory")
        )
        self.lineEdit_browse.setText(self.folder)

    def _plot_refresh(self):

        self.pix1 = self.spinBox_pix1.value()
        self.pix2 = self.spinBox_pix2.value()
        self.board_number = self.comboBox_boardNumber.currentText()
        self.range_left = self.spinBox_rangeLeft.value()
        self.range_right = self.spinBox_rangeRight.value()
        timestamps = self.spinBox_timestamps.value()

        os.chdir(self.folder)

        self.widget_figure._plot_delta(
            self.pix1,
            self.pix2,
            timestamps,
            self.board_number,
            self.range_left,
            self.range_right,
        )



"""Module with scripts for unpacking data from LinoSPAD2.

This file can also be imported as a module and contains the following
functions:

    * unpack_bin - function for unpacking data from LinoSPAD2. Utilizes
    the numpy library to speed up the process. Works with firmware
    versions 2208 and 2212.

"""

import os

import numpy as np

# from daplis_rtp.functions.calibrate import calibrate_load


def unpack_bin(file, board_number: str, fw_ver: str, timestamps: int = 512):
    """Unpack binary data from LinoSPAD2.

    Unpacks binary-encoded .dat files with data from LinoSPAD2 into a
    matrix with dimensions [256, # of timestamps*cycles] for firwmare
    2208, or [64, # of timestamps*cycles + cycles, 2] for firmware
    version 2212 where the third axis contains the timestamp and a pixel
    coordinate in the particular TDC.

    Parameters
    ----------
    file : str
        Name of the '.dat' data file to unpack.
    board_number : str
        LinoSPAD2 daugtherboard number.
    fw_ver : str
        LinoSPAD2 firmware version.
    timestamps : int, optional
        Number of timetstamps per pixel (firmware 2208) or per TDC
        firmware 2212 and per acquisition cycle, by default 512.

    Returns
    -------
    data_matrix: ndarray
        Matrix of timestamps in each pixel (firmware 2208) or in each
        TDC with pixel number in that TDC (firmware 2212).

    Raises
    ------
    FileNotFoundError
        Raised if no calibration data were found.
    """
    # read data by 32 bit words
    rawFile = np.fromfile(file, dtype=np.uint32)
    # lowest 28 bits are the timestamp; convert to longlong, int is not enough
    data_t = (rawFile & 0xFFFFFFF).astype(np.longlong) * 17.857
    # mask nonvalid data with '-1'
    data_t[np.where(rawFile < 0x80000000)] = -1
    # number of acquisition cycles
    if fw_ver == "2208":
        cycles = int(len(data_t) / timestamps / 256)

        data_matrix = (
            data_t.reshape(cycles, 256, timestamps)
            .transpose((1, 0, 2))
            .reshape(256, timestamps * cycles)
        )
    # firmware 2212 additions
    if fw_ver[:-1] == "2212":
        data_p = ((rawFile >> 28) & 0x3).astype(np.longlong)
        cycles = int(len(data_t) / timestamps / 65)
        data_matrix_p = (
            data_p.reshape(cycles, 65, timestamps)
            .transpose((1, 0, 2))
            .reshape(65, timestamps * cycles)
        )

        data_matrix_t = (
            data_t.reshape(cycles, 65, timestamps)
            .transpose((1, 0, 2))
            .reshape(65, timestamps * cycles)
        )

        # cut the 65th TDC that does not hold any actual data from pixels
        data_matrix_p = data_matrix_p[:-1]
        data_matrix_t = data_matrix_t[:-1]
        # insert '-2' at the end of each cycle
        data_matrix_p = np.insert(
            data_matrix_p,
            np.linspace(timestamps, cycles * timestamps, cycles).astype(
                np.longlong
            ),
            -2,
            1,
        )

        data_matrix_t = np.insert(
            data_matrix_t,
            np.linspace(timestamps, cycles * timestamps, cycles).astype(
                np.longlong
            ),
            -2,
            1,
        )

        # combine both matrices into a single one, where each cell holds pix
        # coordinates in the TDC and the timestamp
        data_matrix = np.stack((data_matrix_p, data_matrix_t), axis=2).astype(
            np.longlong
        )

    if fw_ver == "2212s":
        pix_coor = np.arange(256).reshape(4, 64).T
    elif fw_ver == "2212b":
        pix_coor = np.arange(256).reshape(64, 4)
    else:
        pass

    # # path to the current script, two levels up (the script itself is
    # # in the path) and one level down to the calibration data
    # path_calib_data = (
    #     os.path.realpath(__file__) + "../../.." + "/params/calibration_data"
    # )

    # try:
    #     cal_mat = calibrate_load(path_calib_data, board_number)
    # except FileNotFoundError:
    #     raise FileNotFoundError(
    #         "No .csv file with the calibration"
    #         "data was found, check the path "
    #         "or run the calibration."
    #     )

    # if fw_ver == "2208":
    #     for i in range(256):
    #         ind = np.where(data_matrix[i] >= 0)[0]
    #         data_matrix[i, ind] = (
    #             data_matrix[i, ind] - data_matrix[i, ind] % 140
    #         ) * 17.857 + cal_mat[i, (data_matrix[i, ind] % 140)]

    # elif fw_ver[:-1] == "2212":
    #     for i in range(256):
    #         # transform pixel number to TDC number and pixel coordinates in
    #         # that TDC (from 0 to 3)
    #         tdc, pix = np.argwhere(pix_coor == i)[0]
    #         # find data from that pixel
    #         ind = np.where(data_matrix[tdc].T[0] == pix)[0]
    #         # cut non-valid timestamps ('-1's)
    #         ind = ind[np.where(data_matrix[tdc].T[1][ind] >= 0)[0]]
    #         if not np.any(ind):
    #             continue
    #         # apply calibration
    #         data_matrix[tdc].T[1][ind] = (
    #             data_matrix[tdc].T[1][ind] - data_matrix[tdc].T[1][ind] % 140
    #         ) * 17.857 + cal_mat[i, (data_matrix[tdc].T[1][ind] % 140)]

    return data_matrix



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'LiveTimestamps_tab_c.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(874, 636)
        self.gridLayout_2 = QtWidgets.QGridLayout(Form)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.frame_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_comboBox_mask_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mask_2.setEnabled(True)
        self.label_comboBox_mask_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mask_2.setFont(font)
        self.label_comboBox_mask_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_comboBox_mask_2.setObjectName("label_comboBox_mask_2")
        self.horizontalLayout_7.addWidget(self.label_comboBox_mask_2)
        self.comboBox_mask_2 = QtWidgets.QComboBox(self.frame_2)
        self.comboBox_mask_2.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_mask_2.sizePolicy().hasHeightForWidth())
        self.comboBox_mask_2.setSizePolicy(sizePolicy)
        self.comboBox_mask_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_mask_2.setFont(font)
        self.comboBox_mask_2.setObjectName("comboBox_mask_2")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.horizontalLayout_7.addWidget(self.comboBox_mask_2)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout_8.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_8.setSpacing(6)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_comboBox_mb_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mb_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mb_2.setFont(font)
        self.label_comboBox_mb_2.setObjectName("label_comboBox_mb_2")
        self.horizontalLayout_8.addWidget(self.label_comboBox_mb_2)
        self.comboBox_mb_2 = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_mb_2.sizePolicy().hasHeightForWidth())
        self.comboBox_mb_2.setSizePolicy(sizePolicy)
        self.comboBox_mb_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_mb_2.setFont(font)
        self.comboBox_mb_2.setObjectName("comboBox_mb_2")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.horizontalLayout_8.addWidget(self.comboBox_mb_2)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_FW_2 = QtWidgets.QLabel(self.frame_2)
        self.label_FW_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_FW_2.setFont(font)
        self.label_FW_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_FW_2.setObjectName("label_FW_2")
        self.horizontalLayout_9.addWidget(self.label_FW_2)
        self.comboBox_FW_2 = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_FW_2.sizePolicy().hasHeightForWidth())
        self.comboBox_FW_2.setSizePolicy(sizePolicy)
        self.comboBox_FW_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_FW_2.setFont(font)
        self.comboBox_FW_2.setObjectName("comboBox_FW_2")
        self.comboBox_FW_2.addItem("")
        self.comboBox_FW_2.addItem("")
        self.comboBox_FW_2.addItem("")
        self.horizontalLayout_9.addWidget(self.comboBox_FW_2)
        self.verticalLayout.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_timestamps_2 = QtWidgets.QLabel(self.frame_2)
        self.label_timestamps_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_timestamps_2.setFont(font)
        self.label_timestamps_2.setLineWidth(0)
        self.label_timestamps_2.setTextFormat(QtCore.Qt.PlainText)
        self.label_timestamps_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_timestamps_2.setObjectName("label_timestamps_2")
        self.horizontalLayout_11.addWidget(self.label_timestamps_2)
        self.spinBox_timestamps_2 = QtWidgets.QSpinBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_timestamps_2.sizePolicy().hasHeightForWidth())
        self.spinBox_timestamps_2.setSizePolicy(sizePolicy)
        self.spinBox_timestamps_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.spinBox_timestamps_2.setFont(font)
        self.spinBox_timestamps_2.setMaximum(1536)
        self.spinBox_timestamps_2.setProperty("value", 300)
        self.spinBox_timestamps_2.setObjectName("spinBox_timestamps_2")
        self.horizontalLayout_11.addWidget(self.spinBox_timestamps_2)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.checkBox_pix_add_fix = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_pix_add_fix.setFont(font)
        self.checkBox_pix_add_fix.setObjectName("checkBox_pix_add_fix")
        self.verticalLayout.addWidget(self.checkBox_pix_add_fix)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.checkBox_presetMask_2 = QtWidgets.QCheckBox(self.frame_2)
        self.checkBox_presetMask_2.setEnabled(True)
        self.checkBox_presetMask_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_presetMask_2.setFont(font)
        self.checkBox_presetMask_2.setObjectName("checkBox_presetMask_2")
        self.horizontalLayout_10.addWidget(self.checkBox_presetMask_2)
        self.label_presetMaskInfo_2 = QtWidgets.QLabel(self.frame_2)
        self.label_presetMaskInfo_2.setMinimumSize(QtCore.QSize(20, 20))
        self.label_presetMaskInfo_2.setMaximumSize(QtCore.QSize(20, 20))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(160, 226, 227))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(227, 227, 227))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(247, 247, 247))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        self.label_presetMaskInfo_2.setPalette(palette)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_presetMaskInfo_2.setFont(font)
        self.label_presetMaskInfo_2.setCursor(QtGui.QCursor(QtCore.Qt.WhatsThisCursor))
        self.label_presetMaskInfo_2.setAutoFillBackground(True)
        self.label_presetMaskInfo_2.setFrameShape(QtWidgets.QFrame.Box)
        self.label_presetMaskInfo_2.setTextFormat(QtCore.Qt.AutoText)
        self.label_presetMaskInfo_2.setScaledContents(False)
        self.label_presetMaskInfo_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_presetMaskInfo_2.setObjectName("label_presetMaskInfo_2")
        self.horizontalLayout_10.addWidget(self.label_presetMaskInfo_2)
        spacerItem = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem)
        self.pushButton_resetMask_2 = QtWidgets.QPushButton(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_resetMask_2.sizePolicy().hasHeightForWidth())
        self.pushButton_resetMask_2.setSizePolicy(sizePolicy)
        self.pushButton_resetMask_2.setMinimumSize(QtCore.QSize(100, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_resetMask_2.setFont(font)
        self.pushButton_resetMask_2.setObjectName("pushButton_resetMask_2")
        self.horizontalLayout_10.addWidget(self.pushButton_resetMask_2)
        self.verticalLayout.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_TopMostPixels = QtWidgets.QLabel(self.frame_2)
        self.label_TopMostPixels.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_TopMostPixels.setFont(font)
        self.label_TopMostPixels.setObjectName("label_TopMostPixels")
        self.horizontalLayout_2.addWidget(self.label_TopMostPixels)
        self.lcdTopMostPixel1 = QtWidgets.QLCDNumber(self.frame_2)
        self.lcdTopMostPixel1.setObjectName("lcdTopMostPixel1")
        self.horizontalLayout_2.addWidget(self.lcdTopMostPixel1)
        self.lcdTopMostPixel2 = QtWidgets.QLCDNumber(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.lcdTopMostPixel2.setFont(font)
        self.lcdTopMostPixel2.setObjectName("lcdTopMostPixel2")
        self.horizontalLayout_2.addWidget(self.lcdTopMostPixel2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.scrollArea = QtWidgets.QScrollArea(self.frame_2)
        self.scrollArea.setMinimumSize(QtCore.QSize(0, 250))
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 256, 248))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.scrollArea.setWidget(self.scrollAreaWidgetContents_2)
        self.verticalLayout.addWidget(self.scrollArea)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.checkBox_linearScale_2 = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_linearScale_2.setFont(font)
        self.checkBox_linearScale_2.setChecked(True)
        self.checkBox_linearScale_2.setObjectName("checkBox_linearScale_2")
        self.horizontalLayout_12.addWidget(self.checkBox_linearScale_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem1)
        self.checkBox_grouping_2 = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_grouping_2.setFont(font)
        self.checkBox_grouping_2.setObjectName("checkBox_grouping_2")
        self.horizontalLayout_12.addWidget(self.checkBox_grouping_2)
        self.verticalLayout.addLayout(self.horizontalLayout_12)
        self.pushButton_refreshPlot = QtWidgets.QPushButton(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_refreshPlot.setFont(font)
        self.pushButton_refreshPlot.setObjectName("pushButton_refreshPlot")
        self.verticalLayout.addWidget(self.pushButton_refreshPlot)
        self.pushButton_startStream = QtWidgets.QPushButton(self.frame_2)
        self.pushButton_startStream.setMinimumSize(QtCore.QSize(0, 30))
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_startStream.setFont(font)
        self.pushButton_startStream.setObjectName("pushButton_startStream")
        self.verticalLayout.addWidget(self.pushButton_startStream)
        self.gridLayout_2.addWidget(self.frame_2, 0, 1, 1, 1)
        self.frame = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout = QtWidgets.QGridLayout(self.frame)
        self.gridLayout.setObjectName("gridLayout")
        self.pushButton_browse = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_browse.sizePolicy().hasHeightForWidth())
        self.pushButton_browse.setSizePolicy(sizePolicy)
        self.pushButton_browse.setMinimumSize(QtCore.QSize(100, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_browse.setFont(font)
        self.pushButton_browse.setObjectName("pushButton_browse")
        self.gridLayout.addWidget(self.pushButton_browse, 0, 0, 1, 2)
        self.label_leftXLim = QtWidgets.QLabel(self.frame)
        self.label_leftXLim.setMinimumSize(QtCore.QSize(0, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_leftXLim.setFont(font)
        self.label_leftXLim.setObjectName("label_leftXLim")
        self.gridLayout.addWidget(self.label_leftXLim, 6, 0, 1, 1)
        self.widget_figure = QtWidgets.QWidget(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_figure.sizePolicy().hasHeightForWidth())
        self.widget_figure.setSizePolicy(sizePolicy)
        self.widget_figure.setMinimumSize(QtCore.QSize(500, 425))
        font = QtGui.QFont()
        font.setPointSize(15)
        self.widget_figure.setFont(font)
        self.widget_figure.setObjectName("widget_figure")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 1, 3)
        self.horizontalSlider_leftXLim = QtWidgets.QSlider(self.frame)
        self.horizontalSlider_leftXLim.setMinimumSize(QtCore.QSize(0, 28))
        self.horizontalSlider_leftXLim.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_leftXLim.setObjectName("horizontalSlider_leftXLim")
        self.gridLayout.addWidget(self.horizontalSlider_leftXLim, 6, 1, 1, 2)
        self.lineEdit_browse = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_browse.setMinimumSize(QtCore.QSize(0, 28))
        self.lineEdit_browse.setObjectName("lineEdit_browse")
        self.gridLayout.addWidget(self.lineEdit_browse, 0, 2, 1, 1)
        self.label_rightXLim = QtWidgets.QLabel(self.frame)
        self.label_rightXLim.setMinimumSize(QtCore.QSize(0, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_rightXLim.setFont(font)
        self.label_rightXLim.setObjectName("label_rightXLim")
        self.gridLayout.addWidget(self.label_rightXLim, 8, 0, 1, 1)
        self.horizontalSlider_rightXLim = QtWidgets.QSlider(self.frame)
        self.horizontalSlider_rightXLim.setMinimumSize(QtCore.QSize(0, 28))
        self.horizontalSlider_rightXLim.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_rightXLim.setObjectName("horizontalSlider_rightXLim")
        self.gridLayout.addWidget(self.horizontalSlider_rightXLim, 8, 1, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem2, 5, 0, 1, 3)
        self.gridLayout_2.addWidget(self.frame, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label_comboBox_mask_2.setText(_translate("Form", "LinoSPAD2 daughterboard"))
        self.comboBox_mask_2.setItemText(0, _translate("Form", "B7d"))
        self.comboBox_mask_2.setItemText(1, _translate("Form", "NL11"))
        self.comboBox_mask_2.setItemText(2, _translate("Form", "A5"))
        self.comboBox_mask_2.setItemText(3, _translate("Form", "D2b"))
        self.label_comboBox_mb_2.setText(_translate("Form", "LinoSPAD2 motherboard"))
        self.comboBox_mb_2.setItemText(0, _translate("Form", "#28"))
        self.comboBox_mb_2.setItemText(1, _translate("Form", "#33"))
        self.comboBox_mb_2.setItemText(2, _translate("Form", "#21"))
        self.comboBox_mb_2.setItemText(3, _translate("Form", "#36"))
        self.comboBox_mb_2.setItemText(4, _translate("Form", "#37"))
        self.comboBox_mb_2.setItemText(5, _translate("Form", "#4"))
        self.comboBox_mb_2.setItemText(6, _translate("Form", "#29"))
        self.label_FW_2.setText(_translate("Form", "Firmware version"))
        self.comboBox_FW_2.setItemText(0, _translate("Form", "2212b"))
        self.comboBox_FW_2.setItemText(1, _translate("Form", "2208"))
        self.comboBox_FW_2.setItemText(2, _translate("Form", "2212s"))
        self.label_timestamps_2.setToolTip(_translate("Form", "<html><head/><body><p>Number of timestamps per pixel per acquisition cycle. The default is 512.</p></body></html>"))
        self.label_timestamps_2.setText(_translate("Form", "Timestamps"))
        self.checkBox_pix_add_fix.setText(_translate("Form", "Correct pixel addresing"))
        self.checkBox_presetMask_2.setText(_translate("Form", "Preset mask"))
        self.label_presetMaskInfo_2.setToolTip(_translate("Form", "<html><head/><body><p>Mask for warm pixels of a certain LinoSPAD2 board, which can be selected above.</p></body></html>"))
        self.label_presetMaskInfo_2.setText(_translate("Form", "i"))
        self.pushButton_resetMask_2.setText(_translate("Form", "Reset Mask"))
        self.label_TopMostPixels.setText(_translate("Form", "Top-most pixels:"))
        self.checkBox_linearScale_2.setText(_translate("Form", "Linear scale"))
        self.checkBox_grouping_2.setToolTip(_translate("Form", "<html><head/><body><p>Check to plot three vertical lines to help allign the peaks in a single group of 64 pixels.</p></body></html>"))
        self.checkBox_grouping_2.setText(_translate("Form", "Group of 64"))
        self.pushButton_refreshPlot.setText(_translate("Form", "Refresh plot"))
        self.pushButton_startStream.setText(_translate("Form", "Start stream"))
        self.pushButton_browse.setText(_translate("Form", "Browse"))
        self.label_leftXLim.setText(_translate("Form", "Left x limit"))
        self.label_rightXLim.setText(_translate("Form", "Right x limit"))



"""Module for collecting number of timestamps in each pixel.

Works with firmware versions 2208 and 2212.

The following functions are provided.

    * sen-pop - collects the number of timestamps in each pixel for the
    data file provided and returns it as an array.

"""

import numpy as np

from daplis_rtp.functions.unpack import unpack_bin


def sen_pop(
    file,
    board_number,
    fw_ver,
    timestamps: int = 512,
    pix_add_fix: bool = False,
):
    """Collect number of timestamps in each pixel.

    The output is used for plotting the sensor population. Works
    with firmware versions 2208 and 2212.

    Parameters
    ----------
    file : str
        Address of the data file.
    board_number : str
        LinoSPAD2 daughterboard number.
    fw_ver : str
        LinoSPAD2 firmware version.
    timestamps : int, optional
        Number of timestamps per acquisition cycle per pixel/TDC, by
        default 512.

    Returns
    -------
    valid_per_pixel: array-like
        Array of number of timestamps in each pixel.
    """
    if fw_ver == "2208":
        data = unpack_bin(file, board_number, fw_ver, timestamps)
        valid_per_pixel = np.zeros(256)
        for i in range(len(data)):
            valid_per_pixel[i] = len(np.where(data[i] > 0)[0])
    elif fw_ver[:-1] == "2212":
        data = unpack_bin(file, board_number, fw_ver, timestamps)
        valid_per_pixel = np.zeros(256)
        if fw_ver == "2212s":
            pix_coor = np.arange(256).reshape(4, 64).T
        elif fw_ver == "2212b":
            pix_coor = np.arange(256).reshape(64, 4)
        for i in range(256):
            tdc, pix = np.argwhere(pix_coor == i)[0]
            ind = np.where(data[tdc].T[0] == pix)[0]
            ind1 = np.where(data[tdc].T[1][ind] > 0)[0]
            valid_per_pixel[i] += len(data[tdc].T[1][ind[ind1]])

    if pix_add_fix is True:
        fix = np.zeros(len(valid_per_pixel))
        fix[:128] = valid_per_pixel[128:]
        fix[128:] = np.flip(valid_per_pixel[:128])
        valid_per_pixel = fix
        del fix

    return valid_per_pixel



import glob
import os

from PyQt5.QtWidgets import QPushButton, QWidget, QVBoxLayout, QFileDialog, QLineEdit, QCheckBox, \
    QHBoxLayout, QGridLayout, QSlider
from PyQt5.QtCore import pyqtSlot, QTimer, Qt
from app.tools import timestamp_computation
from app.graphic.plot_figure import PltCanvas
import numpy as np
import matplotlib

matplotlib.use("Qt5Agg")


class LiveTimestamps(QWidget):
    def __init__(self, parent):
        super(LiveTimestamps, self).__init__(parent)
        self.mainLayout = QHBoxLayout(self)
        self.setLayout(self.mainLayout)

        self.leftQwidget = QWidget(self)
        self.leftLayout = QVBoxLayout(self)
        self.pushButtonLoadPath = QPushButton("Set path")

        self.xSliderLeft = QSlider(Qt.Horizontal)
        self.xSliderRight = QSlider(Qt.Horizontal)
        self.checkBoxScale = QCheckBox("Linear scale", self)
        self.lineEditPath = QLineEdit('')
        self.refreshBtn = QPushButton("Refresh plot")
        self.pushButtonStartSync = QPushButton("Start stream")
        self.plotWidget = PltCanvas(self)
        self.timer = QTimer()
        self.timerRunning = False
        self.last_file_ctime = 0

        self.pathtotimestamp = ''
        self.leftLayout.addWidget(self.pushButtonLoadPath)
        self.leftLayout.addWidget(self.lineEditPath)
        self.leftLayout.addWidget(self.pushButtonStartSync)
        self.leftLayout.addWidget(self.refreshBtn)
        self.leftLayout.addWidget(self.plotWidget)
        self.leftLayout.addWidget(self.xSliderLeft)
        self.leftLayout.addWidget(self.xSliderRight)
        self.leftLayout.addWidget(self.checkBoxScale)
        self.leftQwidget.setLayout(self.leftLayout)
        self.mainLayout.addWidget(self.leftQwidget)

        self.checkBoxWidget = QWidget(self)
        self.checkBoxLayoutlayout = QGridLayout(self)
        self.checkBoxWidget.setLayout(self.checkBoxLayoutlayout)
        self.checkBoxPixel = []
        self.maskValidPixels = np.zeros(256)
        for clm in range(8):
            for row in range(32):
                self.checkBoxPixel.append(QCheckBox(str(row + clm * 32), self))
                self.checkBoxLayoutlayout.addWidget(self.checkBoxPixel[row + clm * 32], row, clm)
        self.checkBoxWidget.resize(400, 500)
        self.mainLayout.addWidget(self.checkBoxWidget)

        # Add tabs to widget
        self.pushButtonLoadPath.clicked.connect(self.slot_loadpath)
        self.pushButtonStartSync.clicked.connect(self.slot_startstream)
        self.timer.timeout.connect(self.updateTimeStamp)
        self.checkBoxScale.stateChanged.connect(self.slot_checkplotscale)
        self.refreshBtn.clicked.connect(self.slot_refresh)
        self.xSliderLeft.valueChanged.connect(self.slot_updateLeftSlider)
        self.xSliderRight.valueChanged.connect(self.slot_updateRightSlider)

        self.leftPlotLim = 0
        self.rightPlotLim = 255
        self.xSliderLeft.setMinimum(0)
        self.xSliderLeft.setMaximum(255)
        self.xSliderRight.setMinimum(0)
        self.xSliderRight.setMaximum(255)
        self.xSliderRight.setSliderPosition(255)
        self.leftPosition = 0
        self.rightPosition = 255

    def updateTimeStamp(self):
        self.getvalidtimestamps()
        os.chdir(self.pathtotimestamp)
        DATA_FILES = glob.glob('*.dat*')
        print("updateTimeStamp: timer running")
        try:
            last_file = max(DATA_FILES, key=os.path.getctime)
            new_file_ctime = os.path.getctime(last_file)

            if new_file_ctime > self.last_file_ctime:
                # print("updateTimeStamp: new file")
                self.last_file_ctime = new_file_ctime
                # print("updateTimeStamp:" + self.pathtotimestamp + last_file)
                validtimestemps, peak = timestamp_computation.get_nmr_validtimestamps(
                    self.pathtotimestamp + '/' + last_file, np.arange(145, 155, 1), 512)
                validtimestemps = validtimestemps * self.maskValidPixels
                self.plotWidget.setPlotData(np.arange(0, 256, 1), validtimestemps, peak,[self.leftPosition,self.rightPosition])
            # else:
            # print("updateTimeStamp:  not a new file")

        except ValueError:
            print("updateTimeStamp:  waiting for a file")

    def getvalidtimestamps(self):
        for i in range(256):
            if self.checkBoxPixel[i].isChecked():
                self.maskValidPixels[i] = 0
            else:
                self.maskValidPixels[i] = 1

    @pyqtSlot()
    def slot_loadpath(self):
        file = str(QFileDialog.getExistingDirectory(self, "Select Directory"))
        self.lineEditPath.setText(file)
        self.pathtotimestamp = file
        print(file + "\n")

    def slot_startstream(self):
        self.last_file_ctime = 0

        if self.timerRunning is True:
            self.timer.stop()
            self.timerRunning = False
            self.pushButtonStartSync.setText("Start stream")
        else:
            self.pushButtonStartSync.setText("Stop stream")
            self.timer.start(100)
            self.timerRunning = True

    def slot_checkplotscale(self):
        if self.checkBoxScale.isChecked():
            self.plotWidget.setPlotScale(True)
        else:
            self.plotWidget.setPlotScale(False)

    def slot_refresh(self):
        self.updateTimeStamp()
        self.last_file_ctime = 0

    def slot_updateLeftSlider(self):
        if self.xSliderLeft.value() >= self.xSliderRight.value():
            self.xSliderLeft.setValue(self.xSliderRight.value()-1)
        self.leftPosition = self.xSliderLeft.value()


    def slot_updateRightSlider(self):
        if self.xSliderRight.value() <= self.xSliderLeft.value():
            self.xSliderRight.setValue(self.xSliderLeft.value()+1)
        self.rightPosition = self.xSliderRight.value()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'SinglePixelHistogram_tab_c.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(874, 636)
        self.gridLayout_2 = QtWidgets.QGridLayout(Form)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.frame = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout = QtWidgets.QGridLayout(self.frame)
        self.gridLayout.setObjectName("gridLayout")
        self.lineEdit_browse = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_browse.sizePolicy().hasHeightForWidth())
        self.lineEdit_browse.setSizePolicy(sizePolicy)
        self.lineEdit_browse.setMinimumSize(QtCore.QSize(0, 28))
        self.lineEdit_browse.setObjectName("lineEdit_browse")
        self.gridLayout.addWidget(self.lineEdit_browse, 0, 2, 1, 1)
        self.pushButton_browse = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_browse.sizePolicy().hasHeightForWidth())
        self.pushButton_browse.setSizePolicy(sizePolicy)
        self.pushButton_browse.setMinimumSize(QtCore.QSize(100, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_browse.setFont(font)
        self.pushButton_browse.setObjectName("pushButton_browse")
        self.gridLayout.addWidget(self.pushButton_browse, 0, 0, 1, 2)
        self.widget_figure = QtWidgets.QWidget(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_figure.sizePolicy().hasHeightForWidth())
        self.widget_figure.setSizePolicy(sizePolicy)
        self.widget_figure.setMinimumSize(QtCore.QSize(500, 425))
        font = QtGui.QFont()
        font.setPointSize(15)
        self.widget_figure.setFont(font)
        self.widget_figure.setObjectName("widget_figure")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem, 5, 0, 1, 3)
        self.gridLayout_2.addWidget(self.frame, 0, 0, 1, 1)
        self.frame_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_comboBox_mask_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mask_2.setEnabled(True)
        self.label_comboBox_mask_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mask_2.setFont(font)
        self.label_comboBox_mask_2.setToolTip("")
        self.label_comboBox_mask_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_comboBox_mask_2.setObjectName("label_comboBox_mask_2")
        self.horizontalLayout_7.addWidget(self.label_comboBox_mask_2)
        self.comboBox_boardNumber = QtWidgets.QComboBox(self.frame_2)
        self.comboBox_boardNumber.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_boardNumber.sizePolicy().hasHeightForWidth())
        self.comboBox_boardNumber.setSizePolicy(sizePolicy)
        self.comboBox_boardNumber.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_boardNumber.setFont(font)
        self.comboBox_boardNumber.setObjectName("comboBox_boardNumber")
        self.comboBox_boardNumber.addItem("")
        self.comboBox_boardNumber.addItem("")
        self.comboBox_boardNumber.addItem("")
        self.comboBox_boardNumber.addItem("")
        self.horizontalLayout_7.addWidget(self.comboBox_boardNumber)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout_8.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_8.setSpacing(6)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_comboBox_mb_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mb_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mb_2.setFont(font)
        self.label_comboBox_mb_2.setObjectName("label_comboBox_mb_2")
        self.horizontalLayout_8.addWidget(self.label_comboBox_mb_2)
        self.comboBox_mb_2 = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_mb_2.sizePolicy().hasHeightForWidth())
        self.comboBox_mb_2.setSizePolicy(sizePolicy)
        self.comboBox_mb_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_mb_2.setFont(font)
        self.comboBox_mb_2.setObjectName("comboBox_mb_2")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.horizontalLayout_8.addWidget(self.comboBox_mb_2)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_FW_2 = QtWidgets.QLabel(self.frame_2)
        self.label_FW_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_FW_2.setFont(font)
        self.label_FW_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_FW_2.setObjectName("label_FW_2")
        self.horizontalLayout_9.addWidget(self.label_FW_2)
        self.comboBox_FW = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_FW.sizePolicy().hasHeightForWidth())
        self.comboBox_FW.setSizePolicy(sizePolicy)
        self.comboBox_FW.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_FW.setFont(font)
        self.comboBox_FW.setObjectName("comboBox_FW")
        self.comboBox_FW.addItem("")
        self.comboBox_FW.addItem("")
        self.comboBox_FW.addItem("")
        self.horizontalLayout_9.addWidget(self.comboBox_FW)
        self.verticalLayout.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_timestamps_2 = QtWidgets.QLabel(self.frame_2)
        self.label_timestamps_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_timestamps_2.setFont(font)
        self.label_timestamps_2.setLineWidth(0)
        self.label_timestamps_2.setTextFormat(QtCore.Qt.PlainText)
        self.label_timestamps_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_timestamps_2.setObjectName("label_timestamps_2")
        self.horizontalLayout_11.addWidget(self.label_timestamps_2)
        self.spinBox_timestamps = QtWidgets.QSpinBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_timestamps.sizePolicy().hasHeightForWidth())
        self.spinBox_timestamps.setSizePolicy(sizePolicy)
        self.spinBox_timestamps.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.spinBox_timestamps.setFont(font)
        self.spinBox_timestamps.setMaximum(1536)
        self.spinBox_timestamps.setProperty("value", 300)
        self.spinBox_timestamps.setObjectName("spinBox_timestamps")
        self.horizontalLayout_11.addWidget(self.spinBox_timestamps)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setContentsMargins(-1, 0, -1, 7)
        self.horizontalLayout_5.setSpacing(0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_enterPixNumber = QtWidgets.QLabel(self.frame_2)
        self.label_enterPixNumber.setEnabled(True)
        self.label_enterPixNumber.setMinimumSize(QtCore.QSize(100, 30))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_enterPixNumber.setFont(font)
        self.label_enterPixNumber.setTextFormat(QtCore.Qt.AutoText)
        self.label_enterPixNumber.setScaledContents(False)
        self.label_enterPixNumber.setObjectName("label_enterPixNumber")
        self.horizontalLayout_5.addWidget(self.label_enterPixNumber)
        self.spinBox_enterPixNumber = QtWidgets.QSpinBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_enterPixNumber.sizePolicy().hasHeightForWidth())
        self.spinBox_enterPixNumber.setSizePolicy(sizePolicy)
        self.spinBox_enterPixNumber.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.spinBox_enterPixNumber.setFont(font)
        self.spinBox_enterPixNumber.setMaximum(255)
        self.spinBox_enterPixNumber.setProperty("value", 127)
        self.spinBox_enterPixNumber.setObjectName("spinBox_enterPixNumber")
        self.horizontalLayout_5.addWidget(self.spinBox_enterPixNumber)
        self.verticalLayout.addLayout(self.horizontalLayout_5)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_cycle_length = QtWidgets.QLabel(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_cycle_length.setFont(font)
        self.label_cycle_length.setObjectName("label_cycle_length")
        self.horizontalLayout.addWidget(self.label_cycle_length)
        self.lineEdit_cycleLength = QtWidgets.QLineEdit(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.lineEdit_cycleLength.setFont(font)
        self.lineEdit_cycleLength.setObjectName("lineEdit_cycleLength")
        self.horizontalLayout.addWidget(self.lineEdit_cycleLength)
        self.label = QtWidgets.QLabel(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.checkBox_linearScale_2 = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_linearScale_2.setFont(font)
        self.checkBox_linearScale_2.setChecked(True)
        self.checkBox_linearScale_2.setObjectName("checkBox_linearScale_2")
        self.horizontalLayout_12.addWidget(self.checkBox_linearScale_2)
        self.verticalLayout.addLayout(self.horizontalLayout_12)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem1)
        self.pushButton_refreshPlot = QtWidgets.QPushButton(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_refreshPlot.setFont(font)
        self.pushButton_refreshPlot.setObjectName("pushButton_refreshPlot")
        self.verticalLayout.addWidget(self.pushButton_refreshPlot)
        self.gridLayout_2.addWidget(self.frame_2, 0, 1, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton_browse.setText(_translate("Form", "Browse"))
        self.frame_2.setToolTip(_translate("Form", "asdf"))
        self.label_comboBox_mask_2.setText(_translate("Form", "LinoSPAD2 daughterboard"))
        self.comboBox_boardNumber.setItemText(0, _translate("Form", "B7d"))
        self.comboBox_boardNumber.setItemText(1, _translate("Form", "NL11"))
        self.comboBox_boardNumber.setItemText(2, _translate("Form", "A5"))
        self.comboBox_boardNumber.setItemText(3, _translate("Form", "D2b"))
        self.label_comboBox_mb_2.setText(_translate("Form", "LinoSPAD2 motherboard"))
        self.comboBox_mb_2.setItemText(0, _translate("Form", "#28"))
        self.comboBox_mb_2.setItemText(1, _translate("Form", "#33"))
        self.comboBox_mb_2.setItemText(2, _translate("Form", "#21"))
        self.comboBox_mb_2.setItemText(3, _translate("Form", "#36"))
        self.comboBox_mb_2.setItemText(4, _translate("Form", "#37"))
        self.comboBox_mb_2.setItemText(5, _translate("Form", "#4"))
        self.comboBox_mb_2.setItemText(6, _translate("Form", "#29"))
        self.label_FW_2.setText(_translate("Form", "Firmware version"))
        self.comboBox_FW.setItemText(0, _translate("Form", "2212b"))
        self.comboBox_FW.setItemText(1, _translate("Form", "2208"))
        self.comboBox_FW.setItemText(2, _translate("Form", "2212s"))
        self.label_timestamps_2.setToolTip(_translate("Form", "<html><head/><body><p>Number of timestamps per pixel per acquisition cycle. The default is 512.</p></body></html>"))
        self.label_timestamps_2.setText(_translate("Form", "Timestamps"))
        self.label_enterPixNumber.setText(_translate("Form", "Enter pixel index:"))
        self.label_cycle_length.setText(_translate("Form", "Cycle length"))
        self.lineEdit_cycleLength.setText(_translate("Form", "4e9"))
        self.label.setText(_translate("Form", "ps"))
        self.checkBox_linearScale_2.setText(_translate("Form", "Linear scale"))
        self.pushButton_refreshPlot.setText(_translate("Form", "Refresh plot"))
